from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class API_Key(_message.Message):
    __slots__ = ("object_class", "version", "identity", "key")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    identity: str
    key: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., identity: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from fintekkers.requests.valuation import valuation_request_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2
from fintekkers.requests.valuation import valuation_response_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in fintekkers/services/valuation_service/valuation_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ValuationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RunValuation = channel.unary_unary(
                '/fintekkers.services.valuation_service.Valuation/RunValuation',
                request_serializer=fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.FromString,
                _registered_method=True)


class ValuationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RunValuation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ValuationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RunValuation': grpc.unary_unary_rpc_method_handler(
                    servicer.RunValuation,
                    request_deserializer=fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fintekkers.services.valuation_service.Valuation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('fintekkers.services.valuation_service.Valuation', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Valuation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RunValuation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/fintekkers.services.valuation_service.Valuation/RunValuation',
            fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/transaction/query_transaction_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/transaction/query_transaction_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import uuid_pb2 as fintekkers_dot_models_dot_util_dot_uuid__pb2
from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.position import position_filter_pb2 as fintekkers_dot_models_dot_position_dot_position__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?fintekkers/requests/transaction/query_transaction_request.proto\x12\x1f\x66intekkers.requests.transaction\x1a!fintekkers/models/util/uuid.proto\x1a,fintekkers/models/util/local_timestamp.proto\x1a\x30\x66intekkers/models/position/position_filter.proto\"\x95\x02\n\x1cQueryTransactionRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x30\n\x05uuIds\x18\x15 \x03(\x0b\x32!.fintekkers.models.util.UUIDProto\x12Q\n\x18search_transaction_input\x18\x16 \x01(\x0b\x32/.fintekkers.models.position.PositionFilterProto\x12:\n\x05\x61s_of\x18\x17 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\r\n\x05limit\x18\x18 \x01(\x05\x42!B\x1dQueryTransactionRequestProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.transaction.query_transaction_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\035QueryTransactionRequestProtosP\001'
  _globals['_QUERYTRANSACTIONREQUESTPROTO']._serialized_start=232
  _globals['_QUERYTRANSACTIONREQUESTPROTO']._serialized_end=509
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/security-service/security_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/services/security-service/security_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.security import query_security_request_pb2 as fintekkers_dot_requests_dot_security_dot_query__security__request__pb2
from fintekkers.requests.security import query_security_response_pb2 as fintekkers_dot_requests_dot_security_dot_query__security__response__pb2
from fintekkers.requests.security import create_security_request_pb2 as fintekkers_dot_requests_dot_security_dot_create__security__request__pb2
from fintekkers.requests.security import create_security_response_pb2 as fintekkers_dot_requests_dot_security_dot_create__security__response__pb2
from fintekkers.requests.security import get_fields_response_pb2 as fintekkers_dot_requests_dot_security_dot_get__fields__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/services/security-service/security_service.proto\x12$fintekkers.services.security_service\x1a\x39\x66intekkers/requests/security/query_security_request.proto\x1a:fintekkers/requests/security/query_security_response.proto\x1a:fintekkers/requests/security/create_security_request.proto\x1a;fintekkers/requests/security/create_security_response.proto\x1a\x36\x66intekkers/requests/security/get_fields_response.proto\x1a-fintekkers/requests/util/errors/summary.proto\x1a\x1bgoogle/protobuf/empty.proto2\xed\x06\n\x08Security\x12\x85\x01\n\x0e\x43reateOrUpdate\x12\x38.fintekkers.requests.security.CreateSecurityRequestProto\x1a\x39.fintekkers.requests.security.CreateSecurityResponseProto\x12}\n\x08GetByIds\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto\x12}\n\x06Search\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto0\x01\x12|\n\x07ListIds\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto\x12\x81\x01\n\x16ValidateCreateOrUpdate\x12\x38.fintekkers.requests.security.CreateSecurityRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProto\x12~\n\x14ValidateQueryRequest\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProto\x12Y\n\tGetFields\x12\x16.google.protobuf.Empty\x1a\x34.fintekkers.requests.security.GetFieldsResponseProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.security_service.security_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001\220\001\001'
  _globals['_SECURITY']._serialized_start=474
  _globals['_SECURITY']._serialized_end=1351
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.security_service.security_service_pb2', _globals)
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/security/create_security_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/security/create_security_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.security import security_pb2 as fintekkers_dot_models_dot_security_dot_security__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:fintekkers/requests/security/create_security_request.proto\x12\x1c\x66intekkers.requests.security\x1a)fintekkers/models/security/security.proto\"\x86\x01\n\x1a\x43reateSecurityRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x41\n\x0esecurity_input\x18\x14 \x01(\x0b\x32).fintekkers.models.security.SecurityProtoB\x1f\x42\x1b\x43reateSecurityRequestProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.security.create_security_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\033CreateSecurityRequestProtosP\001'
  _globals['_CREATESECURITYREQUESTPROTO']._serialized_start=136
  _globals['_CREATESECURITYREQUESTPROTO']._serialized_end=270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/util/operation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/util/operation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(fintekkers/requests/util/operation.proto\x12\x18\x66intekkers.requests.util*a\n\x19RequestOperationTypeProto\x12\x15\n\x11UNKNOWN_OPERATION\x10\x00\x12\x0c\n\x08VALIDATE\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x07\n\x03GET\x10\x03\x12\n\n\x06SEARCH\x10\x04\x42\rB\tOperationP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.util.operation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\tOperationP\001'
  _globals['_REQUESTOPERATIONTYPEPROTO']._serialized_start=70
  _globals['_REQUESTOPERATIONTYPEPROTO']._serialized_end=167
# @@protoc_insertion_point(module_scope)



from datetime import datetime
from uuid import uuid4, UUID

from google.protobuf.timestamp_pb2 import Timestamp
from fintekkers.models.portfolio.portfolio_pb2 import PortfolioProto
from fintekkers.models.util.local_timestamp_pb2 import LocalTimestampProto
from fintekkers.models.util.uuid_pb2 import UUIDProto
from fintekkers.wrappers.models.util.fintekkers_uuid import FintekkersUuid
from fintekkers.wrappers.models.util.serialization import ProtoSerializationUtil


class Portfolio:
    def __init__(self, proto: PortfolioProto):
        self.proto: PortfolioProto = proto

    def __str__(self):
        return f"ID[{self.proto.uuid}], Portfolio[{self.proto.portfolio_name}]"

    def get_name(self) -> str:
        return self.proto.portfolio_name

    def get_as_of(self) -> datetime:
        as_of: LocalTimestampProto = ProtoSerializationUtil.deserialize(self.proto.as_of)
        return as_of

    def get_uuid(self) -> UUID:
        uuid: FintekkersUuid = ProtoSerializationUtil.deserialize(self.proto.uuid)
        return uuid.as_uuid()


    @staticmethod
    def create_portfolio(portfolio_name: str):
        uuid_value = uuid4()
        portfolio = PortfolioProto(
            as_of=LocalTimestampProto(
                timestamp=Timestamp(), time_zone="America/New_York"
            ),
            is_link=False,
            object_class="Portfolio",
            portfolio_name=portfolio_name,
            uuid=UUIDProto(raw_uuid=uuid_value.bytes),
            version="0.0.1",
        )

        return Portfolio(portfolio)



from fintekkers.models.util import local_timestamp_pb2 as _local_timestamp_pb2
from fintekkers.models.util import uuid_pb2 as _uuid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PortfolioProto(_message.Message):
    __slots__ = ("object_class", "version", "uuid", "as_of", "is_link", "valid_from", "valid_to", "portfolio_name")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    IS_LINK_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_FIELD_NUMBER: _ClassVar[int]
    VALID_TO_FIELD_NUMBER: _ClassVar[int]
    PORTFOLIO_NAME_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    uuid: _uuid_pb2.UUIDProto
    as_of: _local_timestamp_pb2.LocalTimestampProto
    is_link: bool
    valid_from: _local_timestamp_pb2.LocalTimestampProto
    valid_to: _local_timestamp_pb2.LocalTimestampProto
    portfolio_name: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., uuid: _Optional[_Union[_uuid_pb2.UUIDProto, _Mapping]] = ..., as_of: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., is_link: bool = ..., valid_from: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., valid_to: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., portfolio_name: _Optional[str] = ...) -> None: ...



from uuid import UUID, uuid4


class FintekkersUuid:
    uuid: UUID

    def __init__(self, uuid: UUID):
        self.uuid = uuid

    def __str__(self) -> str:
        return self.uuid.__str__()

    @staticmethod
    def from_uuid(uuid: UUID):
        return FintekkersUuid(uuid)

    @staticmethod
    def from_bytes(raw_uuid: list[bytes]):
        return FintekkersUuid(UUID(bytes=raw_uuid))

    @staticmethod
    def new_uuid():
        return FintekkersUuid(uuid4())

    def as_uuid(self) -> UUID:
        return self.uuid

    def as_bytes(self) -> list[bytes]:
        return self.uuid.bytes



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UUIDProto(_message.Message):
    __slots__ = ("raw_uuid",)
    RAW_UUID_FIELD_NUMBER: _ClassVar[int]
    raw_uuid: bytes
    def __init__(self, raw_uuid: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/transaction/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/transaction/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import decimal_value_pb2 as fintekkers_dot_models_dot_util_dot_decimal__value__pb2
from fintekkers.models.util import local_date_pb2 as fintekkers_dot_models_dot_util_dot_local__date__pb2
from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.util import uuid_pb2 as fintekkers_dot_models_dot_util_dot_uuid__pb2
from fintekkers.models.portfolio import portfolio_pb2 as fintekkers_dot_models_dot_portfolio_dot_portfolio__pb2
from fintekkers.models.strategy import strategy_allocation_pb2 as fintekkers_dot_models_dot_strategy_dot_strategy__allocation__pb2
from fintekkers.models.security import security_pb2 as fintekkers_dot_models_dot_security_dot_security__pb2
from fintekkers.models.price import price_pb2 as fintekkers_dot_models_dot_price_dot_price__pb2
from fintekkers.models.position import position_status_pb2 as fintekkers_dot_models_dot_position_dot_position__status__pb2
from fintekkers.models.transaction import transaction_type_pb2 as fintekkers_dot_models_dot_transaction_dot_transaction__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/fintekkers/models/transaction/transaction.proto\x12\x1d\x66intekkers.models.transaction\x1a*fintekkers/models/util/decimal_value.proto\x1a\'fintekkers/models/util/local_date.proto\x1a,fintekkers/models/util/local_timestamp.proto\x1a!fintekkers/models/util/uuid.proto\x1a+fintekkers/models/portfolio/portfolio.proto\x1a\x34\x66intekkers/models/strategy/strategy_allocation.proto\x1a)fintekkers/models/security/security.proto\x1a#fintekkers/models/price/price.proto\x1a\x30\x66intekkers/models/position/position_status.proto\x1a\x34\x66intekkers/models/transaction/transaction_type.proto\"\x83\x08\n\x10TransactionProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12/\n\x04uuid\x18\x05 \x01(\x0b\x32!.fintekkers.models.util.UUIDProto\x12:\n\x05\x61s_of\x18\x06 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\x0f\n\x07is_link\x18\x07 \x01(\x08\x12?\n\nvalid_from\x18\x08 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12=\n\x08valid_to\x18\t \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12>\n\tportfolio\x18\n \x01(\x0b\x32+.fintekkers.models.portfolio.PortfolioProto\x12;\n\x08security\x18\x0b \x01(\x0b\x32).fintekkers.models.security.SecurityProto\x12M\n\x10transaction_type\x18\x0c \x01(\x0e\x32\x33.fintekkers.models.transaction.TransactionTypeProto\x12;\n\x08quantity\x18\r \x01(\x0b\x32).fintekkers.models.util.DecimalValueProto\x12\x32\n\x05price\x18\x0e \x01(\x0b\x32#.fintekkers.models.price.PriceProto\x12:\n\ntrade_date\x18\x0f \x01(\x0b\x32&.fintekkers.models.util.LocalDateProto\x12?\n\x0fsettlement_date\x18\x10 \x01(\x0b\x32&.fintekkers.models.util.LocalDateProto\x12J\n\x11\x63hildTransactions\x18\x14 \x03(\x0b\x32/.fintekkers.models.transaction.TransactionProto\x12H\n\x0fposition_status\x18\x19 \x01(\x0e\x32/.fintekkers.models.position.PositionStatusProto\x12\x12\n\ntrade_name\x18\x1a \x01(\t\x12P\n\x13strategy_allocation\x18\x1b \x01(\x0b\x32\x33.fintekkers.models.strategy.StrategyAllocationProto\x12\x14\n\x0cis_cancelled\x18\x1e \x01(\x08\x42\x15\x42\x11TransactionProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.transaction.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\021TransactionProtosP\001'
  _globals['_TRANSACTIONPROTO']._serialized_start=532
  _globals['_TRANSACTIONPROTO']._serialized_end=1559
# @@protoc_insertion_point(module_scope)



from fintekkers.requests.util.errors import message_pb2 as _message_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorCode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_ERROR: _ClassVar[ErrorCode]
    WARNING: _ClassVar[ErrorCode]
UNKNOWN_ERROR: ErrorCode
WARNING: ErrorCode

class ErrorProto(_message.Message):
    __slots__ = ("code", "detail")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    code: ErrorCode
    detail: _message_pb2.Message
    def __init__(self, code: _Optional[_Union[ErrorCode, str]] = ..., detail: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...

class WarningProto(_message.Message):
    __slots__ = ("code", "detail")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    code: ErrorCode
    detail: _message_pb2.Message
    def __init__(self, code: _Optional[_Union[ErrorCode, str]] = ..., detail: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...



from fintekkers.models.util import uuid_pb2 as _uuid_pb2
from fintekkers.models.util import local_timestamp_pb2 as _local_timestamp_pb2
from fintekkers.models.position import position_filter_pb2 as _position_filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryTransactionRequestProto(_message.Message):
    __slots__ = ("object_class", "version", "uuIds", "search_transaction_input", "as_of", "limit")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UUIDS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TRANSACTION_INPUT_FIELD_NUMBER: _ClassVar[int]
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    uuIds: _containers.RepeatedCompositeFieldContainer[_uuid_pb2.UUIDProto]
    search_transaction_input: _position_filter_pb2.PositionFilterProto
    as_of: _local_timestamp_pb2.LocalTimestampProto
    limit: int
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., uuIds: _Optional[_Iterable[_Union[_uuid_pb2.UUIDProto, _Mapping]]] = ..., search_transaction_input: _Optional[_Union[_position_filter_pb2.PositionFilterProto, _Mapping]] = ..., as_of: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., limit: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/transaction-service/transaction_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/services/transaction-service/transaction_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.transaction import create_transaction_request_pb2 as fintekkers_dot_requests_dot_transaction_dot_create__transaction__request__pb2
from fintekkers.requests.transaction import create_transaction_response_pb2 as fintekkers_dot_requests_dot_transaction_dot_create__transaction__response__pb2
from fintekkers.requests.transaction import query_transaction_request_pb2 as fintekkers_dot_requests_dot_transaction_dot_query__transaction__request__pb2
from fintekkers.requests.transaction import query_transaction_response_pb2 as fintekkers_dot_requests_dot_transaction_dot_query__transaction__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAfintekkers/services/transaction-service/transaction_service.proto\x12\'fintekkers.services.transaction_service\x1a@fintekkers/requests/transaction/create_transaction_request.proto\x1a\x41\x66intekkers/requests/transaction/create_transaction_response.proto\x1a?fintekkers/requests/transaction/query_transaction_request.proto\x1a@fintekkers/requests/transaction/query_transaction_response.proto\x1a-fintekkers/requests/util/errors/summary.proto2\xd5\x06\n\x0bTransaction\x12\x91\x01\n\x0e\x43reateOrUpdate\x12>.fintekkers.requests.transaction.CreateTransactionRequestProto\x1a?.fintekkers.requests.transaction.CreateTransactionResponseProto\x12\x89\x01\n\x08GetByIds\x12=.fintekkers.requests.transaction.QueryTransactionRequestProto\x1a>.fintekkers.requests.transaction.QueryTransactionResponseProto\x12\x89\x01\n\x06Search\x12=.fintekkers.requests.transaction.QueryTransactionRequestProto\x1a>.fintekkers.requests.transaction.QueryTransactionResponseProto0\x01\x12\x88\x01\n\x07ListIds\x12=.fintekkers.requests.transaction.QueryTransactionRequestProto\x1a>.fintekkers.requests.transaction.QueryTransactionResponseProto\x12\x87\x01\n\x16ValidateCreateOrUpdate\x12>.fintekkers.requests.transaction.CreateTransactionRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProto\x12\x84\x01\n\x14ValidateQueryRequest\x12=.fintekkers.requests.transaction.QueryTransactionRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.transaction_service.transaction_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001\220\001\001'
  _globals['_TRANSACTION']._serialized_start=422
  _globals['_TRANSACTION']._serialized_end=1275
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.transaction_service.transaction_service_pb2', _globals)
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class AuctionTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_AUCTION_TYPE: _ClassVar[AuctionTypeProto]
    SINGLE_PRICE: _ClassVar[AuctionTypeProto]
UNKNOWN_AUCTION_TYPE: AuctionTypeProto
SINGLE_PRICE: AuctionTypeProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/valuation/valuation_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/valuation/valuation_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.security import security_pb2 as fintekkers_dot_models_dot_security_dot_security__pb2
from fintekkers.models.position import position_pb2 as fintekkers_dot_models_dot_position_dot_position__pb2
from fintekkers.models.price import price_pb2 as fintekkers_dot_models_dot_price_dot_price__pb2
from fintekkers.requests.util import operation_pb2 as fintekkers_dot_requests_dot_util_dot_operation__pb2
from fintekkers.models.position import measure_pb2 as fintekkers_dot_models_dot_position_dot_measure__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5fintekkers/requests/valuation/valuation_request.proto\x12\x1d\x66intekkers.requests.valuation\x1a)fintekkers/models/security/security.proto\x1a)fintekkers/models/position/position.proto\x1a#fintekkers/models/price/price.proto\x1a(fintekkers/requests/util/operation.proto\x1a(fintekkers/models/position/measure.proto\"\x87\x03\n\x15ValuationRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12K\n\x0eoperation_type\x18\n \x01(\x0e\x32\x33.fintekkers.requests.util.RequestOperationTypeProto\x12:\n\x08measures\x18\x1e \x03(\x0e\x32(.fintekkers.models.position.MeasureProto\x12\x41\n\x0esecurity_input\x18\x14 \x01(\x0b\x32).fintekkers.models.security.SecurityProto\x12\x41\n\x0eposition_input\x18\x15 \x01(\x0b\x32).fintekkers.models.position.PositionProto\x12\x38\n\x0bprice_input\x18\x16 \x01(\x0b\x32#.fintekkers.models.price.PriceProtoB\x1a\x42\x16ValuationRequestProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.valuation.valuation_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\026ValuationRequestProtosP\001'
  _globals['_VALUATIONREQUESTPROTO']._serialized_start=296
  _globals['_VALUATIONREQUESTPROTO']._serialized_end=687
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from fintekkers.requests.util.lock import lock_request_pb2 as _lock_request_pb2
from fintekkers.requests.util.lock import lock_response_pb2 as _lock_response_pb2
from fintekkers.models.util.lock import node_partition_pb2 as _node_partition_pb2
from fintekkers.models.util.lock import node_state_pb2 as _node_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NamespaceList(_message.Message):
    __slots__ = ("namespaces",)
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    namespaces: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, namespaces: _Optional[_Iterable[str]] = ...) -> None: ...

class PartitionsList(_message.Message):
    __slots__ = ("partitions",)
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    partitions: _containers.RepeatedCompositeFieldContainer[_node_partition_pb2.NodePartition]
    def __init__(self, partitions: _Optional[_Iterable[_Union[_node_partition_pb2.NodePartition, _Mapping]]] = ...) -> None: ...

class NodeStateList(_message.Message):
    __slots__ = ("nodes",)
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_state_pb2.NodeState]
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_state_pb2.NodeState, _Mapping]]] = ...) -> None: ...

class CreateNamespaceRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreatePartitionRequest(_message.Message):
    __slots__ = ("name", "partition")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    name: str
    partition: int
    def __init__(self, name: _Optional[str] = ..., partition: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SecurityQuantityTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_QUANTITY_TYPE: _ClassVar[SecurityQuantityTypeProto]
    ORIGINAL_FACE_VALUE: _ClassVar[SecurityQuantityTypeProto]
    NOTIONAL: _ClassVar[SecurityQuantityTypeProto]
    UNITS: _ClassVar[SecurityQuantityTypeProto]
UNKNOWN_QUANTITY_TYPE: SecurityQuantityTypeProto
ORIGINAL_FACE_VALUE: SecurityQuantityTypeProto
NOTIONAL: SecurityQuantityTypeProto
UNITS: SecurityQuantityTypeProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/bond/auction_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/bond/auction_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2fintekkers/models/security/bond/auction_type.proto\x12\x1f\x66intekkers.models.security.bond*>\n\x10\x41uctionTypeProto\x12\x18\n\x14UNKNOWN_AUCTION_TYPE\x10\x00\x12\x10\n\x0cSINGLE_PRICE\x10\x01\x42\x15\x42\x11\x41uctionTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.bond.auction_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\021AuctionTypeProtosP\001'
  _globals['_AUCTIONTYPEPROTO']._serialized_start=87
  _globals['_AUCTIONTYPEPROTO']._serialized_end=149
# @@protoc_insertion_point(module_scope)



from fintekkers.models.util import decimal_value_pb2 as _decimal_value_pb2
from fintekkers.models.util import local_date_pb2 as _local_date_pb2
from fintekkers.models.util import local_timestamp_pb2 as _local_timestamp_pb2
from fintekkers.models.util import uuid_pb2 as _uuid_pb2
from fintekkers.models.portfolio import portfolio_pb2 as _portfolio_pb2
from fintekkers.models.strategy import strategy_allocation_pb2 as _strategy_allocation_pb2
from fintekkers.models.security import security_pb2 as _security_pb2
from fintekkers.models.price import price_pb2 as _price_pb2
from fintekkers.models.position import position_status_pb2 as _position_status_pb2
from fintekkers.models.transaction import transaction_type_pb2 as _transaction_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionProto(_message.Message):
    __slots__ = ("object_class", "version", "uuid", "as_of", "is_link", "valid_from", "valid_to", "portfolio", "security", "transaction_type", "quantity", "price", "trade_date", "settlement_date", "childTransactions", "position_status", "trade_name", "strategy_allocation", "is_cancelled")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    IS_LINK_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_FIELD_NUMBER: _ClassVar[int]
    VALID_TO_FIELD_NUMBER: _ClassVar[int]
    PORTFOLIO_FIELD_NUMBER: _ClassVar[int]
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    TRADE_DATE_FIELD_NUMBER: _ClassVar[int]
    SETTLEMENT_DATE_FIELD_NUMBER: _ClassVar[int]
    CHILDTRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    POSITION_STATUS_FIELD_NUMBER: _ClassVar[int]
    TRADE_NAME_FIELD_NUMBER: _ClassVar[int]
    STRATEGY_ALLOCATION_FIELD_NUMBER: _ClassVar[int]
    IS_CANCELLED_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    uuid: _uuid_pb2.UUIDProto
    as_of: _local_timestamp_pb2.LocalTimestampProto
    is_link: bool
    valid_from: _local_timestamp_pb2.LocalTimestampProto
    valid_to: _local_timestamp_pb2.LocalTimestampProto
    portfolio: _portfolio_pb2.PortfolioProto
    security: _security_pb2.SecurityProto
    transaction_type: _transaction_type_pb2.TransactionTypeProto
    quantity: _decimal_value_pb2.DecimalValueProto
    price: _price_pb2.PriceProto
    trade_date: _local_date_pb2.LocalDateProto
    settlement_date: _local_date_pb2.LocalDateProto
    childTransactions: _containers.RepeatedCompositeFieldContainer[TransactionProto]
    position_status: _position_status_pb2.PositionStatusProto
    trade_name: str
    strategy_allocation: _strategy_allocation_pb2.StrategyAllocationProto
    is_cancelled: bool
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., uuid: _Optional[_Union[_uuid_pb2.UUIDProto, _Mapping]] = ..., as_of: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., is_link: bool = ..., valid_from: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., valid_to: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., portfolio: _Optional[_Union[_portfolio_pb2.PortfolioProto, _Mapping]] = ..., security: _Optional[_Union[_security_pb2.SecurityProto, _Mapping]] = ..., transaction_type: _Optional[_Union[_transaction_type_pb2.TransactionTypeProto, str]] = ..., quantity: _Optional[_Union[_decimal_value_pb2.DecimalValueProto, _Mapping]] = ..., price: _Optional[_Union[_price_pb2.PriceProto, _Mapping]] = ..., trade_date: _Optional[_Union[_local_date_pb2.LocalDateProto, _Mapping]] = ..., settlement_date: _Optional[_Union[_local_date_pb2.LocalDateProto, _Mapping]] = ..., childTransactions: _Optional[_Iterable[_Union[TransactionProto, _Mapping]]] = ..., position_status: _Optional[_Union[_position_status_pb2.PositionStatusProto, str]] = ..., trade_name: _Optional[str] = ..., strategy_allocation: _Optional[_Union[_strategy_allocation_pb2.StrategyAllocationProto, _Mapping]] = ..., is_cancelled: bool = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[TransactionTypeProto]
    BUY: _ClassVar[TransactionTypeProto]
    SELL: _ClassVar[TransactionTypeProto]
    DEPOSIT: _ClassVar[TransactionTypeProto]
    WITHDRAWAL: _ClassVar[TransactionTypeProto]
    MATURATION: _ClassVar[TransactionTypeProto]
    MATURATION_OFFSET: _ClassVar[TransactionTypeProto]
UNKNOWN: TransactionTypeProto
BUY: TransactionTypeProto
SELL: TransactionTypeProto
DEPOSIT: TransactionTypeProto
WITHDRAWAL: TransactionTypeProto
MATURATION: TransactionTypeProto
MATURATION_OFFSET: TransactionTypeProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/lock-service/lock_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/services/lock-service/lock_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fintekkers.requests.util.lock import lock_request_pb2 as fintekkers_dot_requests_dot_util_dot_lock_dot_lock__request__pb2
from fintekkers.requests.util.lock import lock_response_pb2 as fintekkers_dot_requests_dot_util_dot_lock_dot_lock__response__pb2
from fintekkers.models.util.lock import node_partition_pb2 as fintekkers_dot_models_dot_util_dot_lock_dot_node__partition__pb2
from fintekkers.models.util.lock import node_state_pb2 as fintekkers_dot_models_dot_util_dot_lock_dot_node__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3fintekkers/services/lock-service/lock_service.proto\x12 fintekkers.services.lock_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x30\x66intekkers/requests/util/lock/lock_request.proto\x1a\x31\x66intekkers/requests/util/lock/lock_response.proto\x1a\x30\x66intekkers/models/util/lock/node_partition.proto\x1a,fintekkers/models/util/lock/node_state.proto\"#\n\rNamespaceList\x12\x12\n\nnamespaces\x18\x01 \x03(\t\"P\n\x0ePartitionsList\x12>\n\npartitions\x18\x01 \x03(\x0b\x32*.fintekkers.models.util.lock.NodePartition\"F\n\rNodeStateList\x12\x35\n\x05nodes\x18\x01 \x03(\x0b\x32&.fintekkers.models.util.lock.NodeState\"&\n\x16\x43reateNamespaceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"9\n\x16\x43reatePartitionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\x05\x32\xc1\x07\n\x04Lock\x12n\n\tClaimLock\x12/.fintekkers.requests.util.lock.LockRequestProto\x1a\x30.fintekkers.requests.util.lock.LockResponseProto\x12Z\n\x16SubscribeToLockUpdates\x12\x16.google.protobuf.Empty\x1a&.fintekkers.models.util.lock.NodeState0\x01\x12\x63\n\x0f\x43reateNamespace\x12\x38.fintekkers.services.lock_service.CreateNamespaceRequest\x1a\x16.google.protobuf.Empty\x12\x63\n\x0f\x43reatePartition\x12\x38.fintekkers.services.lock_service.CreatePartitionRequest\x1a\x16.google.protobuf.Empty\x12Y\n\x0eListNamespaces\x12\x16.google.protobuf.Empty\x1a/.fintekkers.services.lock_service.NamespaceList\x12s\n\x0eListPartitions\x12/.fintekkers.services.lock_service.NamespaceList\x1a\x30.fintekkers.services.lock_service.PartitionsList\x12`\n\x15GetAllPartitionStatus\x12\x16.google.protobuf.Empty\x1a/.fintekkers.services.lock_service.NodeStateList\x12\x86\x01\n\"GetAllPartitionStatusForNamespaces\x12/.fintekkers.services.lock_service.NamespaceList\x1a/.fintekkers.services.lock_service.NodeStateList\x12h\n\x12GetPartitionStatus\x12*.fintekkers.models.util.lock.NodePartition\x1a&.fintekkers.models.util.lock.NodeStateB\x03\x88\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.lock_service.lock_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001'
  _globals['_NAMESPACELIST']._serialized_start=315
  _globals['_NAMESPACELIST']._serialized_end=350
  _globals['_PARTITIONSLIST']._serialized_start=352
  _globals['_PARTITIONSLIST']._serialized_end=432
  _globals['_NODESTATELIST']._serialized_start=434
  _globals['_NODESTATELIST']._serialized_end=504
  _globals['_CREATENAMESPACEREQUEST']._serialized_start=506
  _globals['_CREATENAMESPACEREQUEST']._serialized_end=544
  _globals['_CREATEPARTITIONREQUEST']._serialized_start=546
  _globals['_CREATEPARTITIONREQUEST']._serialized_end=603
  _globals['_LOCK']._serialized_start=606
  _globals['_LOCK']._serialized_end=1567
# @@protoc_insertion_point(module_scope)



from typing import Generator
from uuid import UUID
from fintekkers.models.position.field_pb2 import FieldProto
from fintekkers.models.util.uuid_pb2 import UUIDProto

from fintekkers.requests.security.query_security_response_pb2 import (
    QuerySecurityResponseProto,
)
from fintekkers.services.security_service.security_service_pb2_grpc import SecurityStub

from fintekkers.wrappers.models.security import Security
from fintekkers.wrappers.requests.security import (
    QuerySecurityRequest,
    CreateSecurityRequest,
)
from fintekkers.wrappers.services.util.Environment import EnvConfig


class SecurityService:
    def __init__(self):
        print("SecurityService connecting to: " + EnvConfig.api_url())
        self.stub = SecurityStub(EnvConfig.get_channel())

    def search(self, request: QuerySecurityRequest) -> Generator[Security, None, None]:
        responses = self.stub.Search(request=request.proto)

        try:
            while not responses._is_complete():
                response: QuerySecurityResponseProto = responses.next()

                for security_proto in response.security_response:
                    yield Security(security_proto)
        except StopIteration:
            pass
        except Exception as e:
            print(e)

        # This will send the cancel message to the server to kill the connection
        responses.cancel()

    def create_or_update(self, request: CreateSecurityRequest):
        return self.stub.CreateOrUpdate(request.proto)

    def get_security_by_uuid(uuid: UUID) -> Security:
        """
        Parameters:
            A UUID

        Returns:
            request (SecurityProto): Returns the Security proto for the UUID, or None if doesn't exist
        """
        uuid_proto = UUIDProto(raw_uuid=uuid.bytes)

        request: QuerySecurityRequest = QuerySecurityRequest.create_query_request(
            {
                FieldProto.ID: uuid_proto,
            }
        )

        securities = SecurityService().search(request)

        for security in securities:
            return security



from fintekkers.models.transaction import transaction_pb2 as _transaction_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTransactionRequestProto(_message.Message):
    __slots__ = ("object_class", "version", "create_transaction_input")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TRANSACTION_INPUT_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    create_transaction_input: _transaction_pb2.TransactionProto
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., create_transaction_input: _Optional[_Union[_transaction_pb2.TransactionProto, _Mapping]] = ...) -> None: ...



from fintekkers.models.position import position_pb2 as _position_pb2
from fintekkers.requests.position import query_position_request_pb2 as _query_position_request_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryPositionResponseProto(_message.Message):
    __slots__ = ("object_class", "version", "position_request", "reporting_currency", "positions")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    POSITION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    REPORTING_CURRENCY_FIELD_NUMBER: _ClassVar[int]
    POSITIONS_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    position_request: _query_position_request_pb2.QueryPositionRequestProto
    reporting_currency: str
    positions: _containers.RepeatedCompositeFieldContainer[_position_pb2.PositionProto]
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., position_request: _Optional[_Union[_query_position_request_pb2.QueryPositionRequestProto, _Mapping]] = ..., reporting_currency: _Optional[str] = ..., positions: _Optional[_Iterable[_Union[_position_pb2.PositionProto, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/price/price.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/price/price.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import decimal_value_pb2 as fintekkers_dot_models_dot_util_dot_decimal__value__pb2
from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.util import uuid_pb2 as fintekkers_dot_models_dot_util_dot_uuid__pb2
from fintekkers.models.security import security_pb2 as fintekkers_dot_models_dot_security_dot_security__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fintekkers/models/price/price.proto\x12\x17\x66intekkers.models.price\x1a*fintekkers/models/util/decimal_value.proto\x1a,fintekkers/models/util/local_timestamp.proto\x1a!fintekkers/models/util/uuid.proto\x1a)fintekkers/models/security/security.proto\"\xa8\x03\n\nPriceProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12/\n\x04uuid\x18\x05 \x01(\x0b\x32!.fintekkers.models.util.UUIDProto\x12:\n\x05\x61s_of\x18\x06 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\x0f\n\x07is_link\x18\x07 \x01(\x08\x12?\n\nvalid_from\x18\x08 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12=\n\x08valid_to\x18\t \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\x38\n\x05price\x18\n \x01(\x0b\x32).fintekkers.models.util.DecimalValueProto\x12;\n\x08security\x18\x0b \x01(\x0b\x32).fintekkers.models.security.SecurityProtoB\x0f\x42\x0bPriceProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.price.price_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\013PriceProtosP\001'
  _globals['_PRICEPROTO']._serialized_start=233
  _globals['_PRICEPROTO']._serialized_end=657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/identifier/identifier.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/identifier/identifier.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.security.identifier import identifier_type_pb2 as fintekkers_dot_models_dot_security_dot_identifier_dot_identifier__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6fintekkers/models/security/identifier/identifier.proto\x12\x1a\x66intekkers.models.security\x1a;fintekkers/models/security/identifier/identifier_type.proto\"\x9c\x01\n\x0fIdentifierProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x18\n\x10identifier_value\x18\x05 \x01(\t\x12H\n\x0fidentifier_type\x18\x06 \x01(\x0e\x32/.fintekkers.models.security.IdentifierTypeProtoB\x14\x42\x10IdentifierProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.identifier.identifier_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\020IdentifierProtosP\001'
  _globals['_IDENTIFIERPROTO']._serialized_start=148
  _globals['_IDENTIFIERPROTO']._serialized_end=304
# @@protoc_insertion_point(module_scope)



from typing import Generator

from google.protobuf.any_pb2 import Any
from google.protobuf import wrappers_pb2 as wrappers

from datetime import datetime

from fintekkers.models.portfolio.portfolio_pb2 import PortfolioProto
from fintekkers.models.position.position_filter_pb2 import PositionFilterProto
from fintekkers.models.position.position_util_pb2 import FieldMapEntry
from fintekkers.models.position import field_pb2
from fintekkers.models.util.local_timestamp_pb2 import LocalTimestampProto
from fintekkers.requests.portfolio.create_portfolio_request_pb2 import (
    CreatePortfolioRequestProto,
)
from fintekkers.requests.portfolio.create_portfolio_response_pb2 import (
    CreatePortfolioResponseProto,
)

from fintekkers.requests.portfolio.query_portfolio_request_pb2 import (
    QueryPortfolioRequestProto,
)
from fintekkers.requests.portfolio.query_portfolio_response_pb2 import (
    QueryPortfolioResponseProto,
)

from fintekkers.services.portfolio_service.portfolio_service_pb2_grpc import (
    PortfolioStub,
)

from fintekkers.wrappers.models.portfolio import Portfolio
from fintekkers.wrappers.models.util.serialization import ProtoSerializationUtil
from fintekkers.wrappers.requests.portfolio import (
    CreatePortfolioRequest,
    QueryPortfolioRequest,
)
from fintekkers.wrappers.services.util.Environment import EnvConfig


class PortfolioService:
    def __init__(self):
        print("PortfolioService connecting to: " + EnvConfig.api_url())
        self.stub = PortfolioStub(EnvConfig.get_channel())

    def search(
        self, request: QueryPortfolioRequest
    ) -> Generator[Portfolio, None, None]:
        responses = self.stub.Search(request=request.proto)

        try:
            while not responses._is_complete():
                response: QueryPortfolioResponseProto = responses.next()

                for portfolio_proto in response.portfolio_response:
                    yield Portfolio(portfolio_proto)
        except StopIteration:
            pass
        except Exception as e:
            print(e)

        # This will terminate the request but leave the TCP connection open
        # responses

        self.stub = PortfolioStub(EnvConfig.get_channel())

    def create_or_update(
        self, request: CreatePortfolioRequestProto
    ) -> Generator[Portfolio, None, None]:
        self.stub = PortfolioStub(EnvConfig.get_channel())
        return self.stub.CreateOrUpdate(request)

    def create_portfolio_by_name(self, portfolio_name: str) -> Portfolio:
        """
        Creates a new portfolio with the given portfolio name. Uniqueness
        is defined by the UUID so if you call this multiple times with
        the same value you will have multiple portfolios with the same
        name but different UUIDs.
        """
        create_portfolio_request: CreatePortfolioRequestProto = (
            CreatePortfolioRequest.create_portfolio_request_from_name(portfolio_name)
        )

        responses = self.create_or_update(create_portfolio_request)

        if len(responses.portfolio_response) > 0:
            for portfolio in responses.portfolio_response:
                return Portfolio(portfolio)

        else:
            print("Could not create portfolio. You should call the validate API to check its a valid request")
            return None

    def get_or_create_portfolio_by_name(self, portfolio_name: str) -> Portfolio:
        """
        Returns a single portfolio if it exists, and if it doesn't exist then it is
        created. This does not guarantee that there is only one portfolio with that
        name in the system, but is a helper function that assumes that is the case.
        """
        def wrap_string_to_any(my_string: str):
            my_any = Any()
            my_any.Pack(wrappers.StringValue(value=my_string))
            return my_any

        as_of_proto: LocalTimestampProto = ProtoSerializationUtil.serialize(
            datetime.now()
        )

        portfolio_query = QueryPortfolioRequestProto(
            search_portfolio_input=PositionFilterProto(
                filters=[
                    FieldMapEntry(
                        field=field_pb2.FieldProto.PORTFOLIO_NAME,
                        field_value_packed=wrap_string_to_any(portfolio_name),
                    )
                ]
            ),
            as_of=as_of_proto,
        )

        responses = self.search(QueryPortfolioRequest(portfolio_query))
        portfolios: list[Portfolio] = []

        for portfolio in responses:
            portfolio:PortfolioProto
            portfolios.append(Portfolio(portfolio))

        number_found = len(portfolios)

        if number_found == 0:
            return self.create_portfolio_by_name(portfolio_name=portfolio_name)
        else:
            return portfolios[0]



from fintekkers.models.position import position_util_pb2 as _position_util_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PositionFilterProto(_message.Message):
    __slots__ = ("object_class", "version", "filters")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    filters: _containers.RepeatedCompositeFieldContainer[_position_util_pb2.FieldMapEntry]
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., filters: _Optional[_Iterable[_Union[_position_util_pb2.FieldMapEntry, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class IdentifierTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_IDENTIFIER_TYPE: _ClassVar[IdentifierTypeProto]
    EXCH_TICKER: _ClassVar[IdentifierTypeProto]
    ISIN: _ClassVar[IdentifierTypeProto]
    CUSIP: _ClassVar[IdentifierTypeProto]
    OSI: _ClassVar[IdentifierTypeProto]
    FIGI: _ClassVar[IdentifierTypeProto]
    CASH: _ClassVar[IdentifierTypeProto]
UNKNOWN_IDENTIFIER_TYPE: IdentifierTypeProto
EXCH_TICKER: IdentifierTypeProto
ISIN: IdentifierTypeProto
CUSIP: IdentifierTypeProto
OSI: IdentifierTypeProto
FIGI: IdentifierTypeProto
CASH: IdentifierTypeProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/security_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/security_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.fintekkers/models/security/security_type.proto\x12\x1a\x66intekkers.models.security*|\n\x11SecurityTypeProto\x12\x19\n\x15UNKNOWN_SECURITY_TYPE\x10\x00\x12\x11\n\rCASH_SECURITY\x10\x01\x12\x13\n\x0f\x45QUITY_SECURITY\x10\x02\x12\x11\n\rBOND_SECURITY\x10\x03\x12\x08\n\x04TIPS\x10\x04\x12\x07\n\x03\x46RN\x10\x05\x42\x16\x42\x12SecurityTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.security_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\022SecurityTypeProtosP\001'
  _globals['_SECURITYTYPEPROTO']._serialized_start=78
  _globals['_SECURITYTYPEPROTO']._serialized_end=202
# @@protoc_insertion_point(module_scope)



from fintekkers.models.price import price_pb2 as _price_pb2
from fintekkers.requests.price import create_price_request_pb2 as _create_price_request_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePriceResponseProto(_message.Message):
    __slots__ = ("object_class", "version", "create_price_request", "price_response")
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CREATE_PRICE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PRICE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    object_class: str
    version: str
    create_price_request: _create_price_request_pb2.CreatePriceRequestProto
    price_response: _containers.RepeatedCompositeFieldContainer[_price_pb2.PriceProto]
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., create_price_request: _Optional[_Union[_create_price_request_pb2.CreatePriceRequestProto, _Mapping]] = ..., price_response: _Optional[_Iterable[_Union[_price_pb2.PriceProto, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/transaction/create_transaction_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/transaction/create_transaction_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.transaction import transaction_pb2 as fintekkers_dot_models_dot_transaction_dot_transaction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@fintekkers/requests/transaction/create_transaction_request.proto\x12\x1f\x66intekkers.requests.transaction\x1a/fintekkers/models/transaction/transaction.proto\"\x99\x01\n\x1d\x43reateTransactionRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Q\n\x18\x63reate_transaction_input\x18\x14 \x01(\x0b\x32/.fintekkers.models.transaction.TransactionProtoB\"B\x1e\x43reateTransactionRequestProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.transaction.create_transaction_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\036CreateTransactionRequestProtosP\001'
  _globals['_CREATETRANSACTIONREQUESTPROTO']._serialized_start=151
  _globals['_CREATETRANSACTIONREQUESTPROTO']._serialized_end=304
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TenorTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_TENOR_TYPE: _ClassVar[TenorTypeProto]
    PERPETUAL: _ClassVar[TenorTypeProto]
    TERM: _ClassVar[TenorTypeProto]
UNKNOWN_TENOR_TYPE: TenorTypeProto
PERPETUAL: TenorTypeProto
TERM: TenorTypeProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/identifier/identifier_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/identifier/identifier_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/models/security/identifier/identifier_type.proto\x12\x1a\x66intekkers.models.security*u\n\x13IdentifierTypeProto\x12\x1b\n\x17UNKNOWN_IDENTIFIER_TYPE\x10\x00\x12\x0f\n\x0b\x45XCH_TICKER\x10\x01\x12\x08\n\x04ISIN\x10\x02\x12\t\n\x05\x43USIP\x10\x03\x12\x07\n\x03OSI\x10\x04\x12\x08\n\x04\x46IGI\x10\x05\x12\x08\n\x04\x43\x41SH\x10\x32\x42\x18\x42\x14IdentifierTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.identifier.identifier_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\024IdentifierTypeProtosP\001'
  _globals['_IDENTIFIERTYPEPROTO']._serialized_start=91
  _globals['_IDENTIFIERTYPEPROTO']._serialized_end=208
# @@protoc_insertion_point(module_scope)



from datetime import datetime
from fintekkers.models.util.local_date_pb2 import LocalDateProto

def today_proto():
    return get_date_proto(datetime.now())

def get_date_proto(input_date:str):
    if input_date is None:
        return None

    date = datetime.strptime(input_date, '%Y-%m-%d')
    return get_date_proto(date)

def get_date_proto(date:datetime):
    return LocalDateProto(year=date.year, month=date.month, day=date.day)

def get_date_from_proto(local_date_proto:LocalDateProto) -> datetime:
    return datetime(local_date_proto.year, local_date_proto.month, local_date_proto.day, 1, 1, 1, 1)

def get_date(input_date:str) -> datetime:
    if input_date is None:
        return None

    try:
        return datetime.strptime(input_date, '%Y-%m-%d')
    except:
        try:
            return datetime.strptime(input_date, '%m/%d/%y')
        except:
            return datetime.strptime(input_date, '%m/%d/%Y')

def get_date_as_dict(input_date:str) -> dict:
    date = get_date(input_date)
    return { 'year': date.year, 'month': date.month, 'day': date.day}


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/transaction/transaction_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/transaction/transaction_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4fintekkers/models/transaction/transaction_type.proto\x12\x1d\x66intekkers.models.transaction*z\n\x14TransactionTypeProto\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x12\x0b\n\x07\x44\x45POSIT\x10\x03\x12\x0e\n\nWITHDRAWAL\x10\x04\x12\x0e\n\nMATURATION\x10\x05\x12\x15\n\x11MATURATION_OFFSET\x10\x06\x42\x19\x42\x15TransactionTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.transaction.transaction_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\025TransactionTypeProtosP\001'
  _globals['_TRANSACTIONTYPEPROTO']._serialized_start=87
  _globals['_TRANSACTIONTYPEPROTO']._serialized_end=209
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class MeasureProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_MEASURE: _ClassVar[MeasureProto]
    DIRECTED_QUANTITY: _ClassVar[MeasureProto]
    MARKET_VALUE: _ClassVar[MeasureProto]
    UNADJUSTED_COST_BASIS: _ClassVar[MeasureProto]
    ADJUSTED_COST_BASIS: _ClassVar[MeasureProto]
    CURRENT_YIELD: _ClassVar[MeasureProto]
    YIELD_TO_MATURITY: _ClassVar[MeasureProto]
UNKNOWN_MEASURE: MeasureProto
DIRECTED_QUANTITY: MeasureProto
MARKET_VALUE: MeasureProto
UNADJUSTED_COST_BASIS: MeasureProto
ADJUSTED_COST_BASIS: MeasureProto
CURRENT_YIELD: MeasureProto
YIELD_TO_MATURITY: MeasureProto



import grpc
import os

# Load environment variables from .env file
from dotenv import load_dotenv

load_dotenv()


class EnvConfig:
    @staticmethod
    def get_env_var(key, default=None):
        value = os.environ.get(key)
        if value is None:
            if default is None:
                raise ValueError(f"Environment variable {key} is not set.")
            return default
        return value

    @staticmethod
    def api_key():
        raise NotImplementedError("API keys not supported currently.")
        # return EnvConfig.get_env_var('API_KEY')

    @staticmethod
    def api_url():
        url = EnvConfig.get_env_var('API_URL', "api.fintekkers.org") + ":8082"
        return url

    @staticmethod
    def get_channel() -> grpc.Channel:
        url = EnvConfig.api_url()

        if "localhost" in url or "127.0.0.1" in url:
            return grpc.insecure_channel(url)
        else:
            return grpc.secure_channel(url, grpc.ssl_channel_credentials())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/util/local_date.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/util/local_date.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'fintekkers/models/util/local_date.proto\x12\x16\x66intekkers.models.util\":\n\x0eLocalDateProto\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\r\n\x05month\x18\x02 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.util.local_date_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOCALDATEPROTO']._serialized_start=67
  _globals['_LOCALDATEPROTO']._serialized_end=125
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/position/position_util.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/position/position_util.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from fintekkers.models.position import field_pb2 as fintekkers_dot_models_dot_position_dot_field__pb2
from fintekkers.models.position import measure_pb2 as fintekkers_dot_models_dot_position_dot_measure__pb2
from fintekkers.models.util import decimal_value_pb2 as fintekkers_dot_models_dot_util_dot_decimal__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.fintekkers/models/position/position_util.proto\x12\x1a\x66intekkers.models.position\x1a\x19google/protobuf/any.proto\x1a&fintekkers/models/position/field.proto\x1a(fintekkers/models/position/measure.proto\x1a*fintekkers/models/util/decimal_value.proto\"\x96\x01\n\x0fMeasureMapEntry\x12\x39\n\x07measure\x18\x01 \x01(\x0e\x32(.fintekkers.models.position.MeasureProto\x12H\n\x15measure_decimal_value\x18\x02 \x01(\x0b\x32).fintekkers.models.util.DecimalValueProto\"\x84\x02\n\rFieldMapEntry\x12\x35\n\x05\x66ield\x18\x01 \x01(\x0e\x32&.fintekkers.models.position.FieldProto\x12\x32\n\x12\x66ield_value_packed\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x14\n\nenum_value\x18\x05 \x01(\x05H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x44\n\x08operator\x18\x14 \x01(\x0e\x32\x32.fintekkers.models.position.PositionFilterOperatorB\x14\n\x12\x46ieldMapValueOneOf*\x9a\x01\n\x16PositionFilterOperator\x12\x14\n\x10UNKNOWN_OPERATOR\x10\x00\x12\n\n\x06\x45QUALS\x10\x01\x12\x0e\n\nNOT_EQUALS\x10\x02\x12\r\n\tLESS_THAN\x10\x03\x12\x17\n\x13LESS_THAN_OR_EQUALS\x10\x04\x12\r\n\tMORE_THAN\x10\x05\x12\x17\n\x13MORE_THAN_OR_EQUALS\x10\x06\x42\x16\x42\x12PositionUtilProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.position.position_util_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\022PositionUtilProtosP\001'
  _globals['_POSITIONFILTEROPERATOR']._serialized_start=648
  _globals['_POSITIONFILTEROPERATOR']._serialized_end=802
  _globals['_MEASUREMAPENTRY']._serialized_start=232
  _globals['_MEASUREMAPENTRY']._serialized_end=382
  _globals['_FIELDMAPENTRY']._serialized_start=385
  _globals['_FIELDMAPENTRY']._serialized_end=645
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class CouponFrequencyProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_COUPON_FREQUENCY: _ClassVar[CouponFrequencyProto]
    ANNUALLY: _ClassVar[CouponFrequencyProto]
    SEMIANNUALLY: _ClassVar[CouponFrequencyProto]
    QUARTERLY: _ClassVar[CouponFrequencyProto]
    MONTHLY: _ClassVar[CouponFrequencyProto]
    NO_COUPON: _ClassVar[CouponFrequencyProto]
UNKNOWN_COUPON_FREQUENCY: CouponFrequencyProto
ANNUALLY: CouponFrequencyProto
SEMIANNUALLY: CouponFrequencyProto
QUARTERLY: CouponFrequencyProto
MONTHLY: CouponFrequencyProto
NO_COUPON: CouponFrequencyProto



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/position-service/position_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/services/position-service/position_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.position import query_position_request_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__request__pb2
from fintekkers.requests.position import query_position_response_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/services/position-service/position_service.proto\x12$fintekkers.services.position_service\x1a\x39\x66intekkers/requests/position/query_position_request.proto\x1a:fintekkers/requests/position/query_position_response.proto\x1a-fintekkers/requests/util/errors/summary.proto2\x89\x02\n\x08Position\x12}\n\x06Search\x12\x37.fintekkers.requests.position.QueryPositionRequestProto\x1a\x38.fintekkers.requests.position.QueryPositionResponseProto0\x01\x12~\n\x14ValidateQueryRequest\x12\x37.fintekkers.requests.position.QueryPositionRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.position_service.position_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001\220\001\001'
  _globals['_POSITION']._serialized_start=268
  _globals['_POSITION']._serialized_end=533
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.position_service.position_service_pb2', _globals)
# @@protoc_insertion_point(module_scope)
